﻿using System.Collections.Specialized;
using MvpStoreFront.Business.Enumerations;

namespace MvpStoreFront.Business.ComponentInterfaces
{
    /// <summary>
    /// Component used for navigating in the webapp
    /// </summary>
    public interface INavigationComponent
    {
        /// <summary>
        /// Navigates to a page uniquely identified by the page identifier, passing the specifief querystring parameters.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        /// <param name="queryString">The query string.</param>
        void NavigateTo(PageIdentifier pageIdentifier, NameValueCollection queryString);

        /// <summary>
        /// Navigates to a page uniquely identified by the page identifier, passing the specifief querystring parameters.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        void NavigateTo(PageIdentifier pageIdentifier);
        /// <summary>
        /// Navigates to a page uniquely identified by the page identifier, passing the specifief querystring parameters.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        /// <param name="param1">The param1.</param>
        /// <param name="value1">The value1.</param>
        void NavigateTo(PageIdentifier pageIdentifier, QueryStringParameter param1, string value1);
        /// <summary>
        /// Navigates to a page uniquely identified by the page identifier, passing the specifief querystring parameters.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        /// <param name="param1">The param1.</param>
        /// <param name="value1">The value1.</param>
        /// <param name="param2">The param2.</param>
        /// <param name="value2">The value2.</param>
        void NavigateTo(PageIdentifier pageIdentifier, QueryStringParameter param1, string value1, QueryStringParameter param2, string value2);

        /// <summary>
        /// Navigates to a page uniquely identified by the page identifier, passing the specifief querystring parameters.
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        /// <param name="param1">The param1.</param>
        /// <param name="value1">The value1.</param>
        /// <param name="param2">The param2.</param>
        /// <param name="value2">The value2.</param>
        /// <param name="param3">The param3.</param>
        /// <param name="value3">The value3.</param>
        void NavigateTo(PageIdentifier pageIdentifier, QueryStringParameter param1, string value1, QueryStringParameter param2, string value2, QueryStringParameter param3, string value3);

        /// <summary>
        /// Gets the URL for the specified control.
        /// </summary>
        /// <param name="identifier">The control identifier.</param>
        /// <returns></returns>
        string GetUrl(ControlIdentifier identifier);

        /// <summary>
        /// Refreshes the current page.
        /// </summary>
        void Refresh();

        /// <summary>
        /// Navigates to a specified page, stocking the current Url in the querystring, so we can return later, calling "ReturnToCaller".
        /// </summary>
        /// <param name="pageIdentifier">The page identifier.</param>
        void NavigateAndReturnTo(PageIdentifier pageIdentifier);

        /// <summary>
        /// Gets a previously stocked Url from the querystring, and navigates to it.
        /// </summary>
        bool ReturnToCaller();

        /// <summary>
        /// Gets the URL for the specified page.
        /// </summary>
        /// <param name="identifier">The page identifier.</param>
        /// <param name="queryString">The query string.</param>
        /// <returns></returns>
        string GetUrl(PageIdentifier identifier, NameValueCollection queryString);

        /// <summary>
        /// Stronlgy type GetUrl overloads
        /// </summary>
        /// <param name="identifier">The identifier.</param>
        /// <returns></returns>
        string GetUrl(PageIdentifier identifier);

        /// <summary>
        /// Stronlgy typed GetUrl overloads
        /// </summary>
        /// <param name="identifier">The identifier.</param>
        /// <param name="param1">The param1.</param>
        /// <param name="value1">The value1.</param>
        /// <returns></returns>
        string GetUrl(PageIdentifier identifier, QueryStringParameter param1, string value1);

        /// <summary>
        /// Stronlgy typed GetUrl overloads
        /// </summary>
        /// <param name="identifier">The identifier.</param>
        /// <param name="param1">The param1.</param>
        /// <param name="value1">The value1.</param>
        /// <param name="param2">The param2.</param>
        /// <param name="value2">The value2.</param>
        /// <returns></returns>
        string GetUrl(PageIdentifier identifier, QueryStringParameter param1, string value1, QueryStringParameter param2, string value2);

        /// <summary>
        /// Stronlgy typed GetUrl overloads
        /// </summary>
        /// <param name="identifier">The identifier.</param>
        /// <param name="param1">The param1.</param>
        /// <param name="value1">The value1.</param>
        /// <param name="param2">The param2.</param>
        /// <param name="value2">The value2.</param>
        /// <param name="param3">The param3.</param>
        /// <param name="value3">The value3.</param>
        /// <returns></returns>
        string GetUrl(PageIdentifier identifier, QueryStringParameter param1, string value1, QueryStringParameter param2, string value2, QueryStringParameter param3, string value3);
    }
}