﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Moq;
using Moq.Stub;
using MvpStoreFront.Business;
using MvpStoreFront.Business.ComponentInterfaces;
using MvpStoreFront.Business.DomainObjects;
using MvpStoreFront.Business.Enumerations;
using MvpStoreFront.Business.ViewInterfaces;
using MvpStoreFront.Business.Presenters;

namespace MvpStoreFront.Tests
{
    [TestClass]
    public class PresenterTests
    {
        [TestInitialize]
        public void Setup()
        {
            ServiceLocator.Instance().InitializeForUnitTesting();
            var mockedNavigation = new Mock<INavigationComponent>();
            ServiceLocator.Instance().RegisterInstance(mockedNavigation.Object);
            var mockedRepository = new Mock<INorthwindRepository>();
            mockedRepository.Expect(x => x.GetCategories()).Returns(new List<Category>(){
                new Category() { CategoryID = 1 }, 
                new Category() { CategoryID = 2 }});
            ServiceLocator.Instance().RegisterInstance(mockedRepository.Object);
        }
        [TestMethod]
        public void Categories_presenter_should_set_all_categories_in_view()
        {
            var mockedView = new Mock<ICategories>();
            mockedView.StubAll();
            var presenterUnderTest = new CategoriesPresenter(mockedView.Object);
            presenterUnderTest.LoadViewFromModel();
            Assert.IsNotNull(mockedView.Object.CategoryList);
            Assert.AreEqual(2, mockedView.Object.CategoryList.Count);
        }
    }
}
